summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2007-10-08 16:41:15 +0000
committerDavid Robillard <d@drobilla.net>2007-10-08 16:41:15 +0000
commitbade64c9aca86225fa37950c17aabc02a3f4a041 (patch)
tree7715b81ce4dbd46556196bbbcc2aa491ac003639 /src
parentd9d735f5fcac1d0f9bbb9eaf5896d5b5b2ac74df (diff)
downloadingen-bade64c9aca86225fa37950c17aabc02a3f4a041.tar.gz
ingen-bade64c9aca86225fa37950c17aabc02a3f4a041.tar.bz2
ingen-bade64c9aca86225fa37950c17aabc02a3f4a041.zip
Serializer -> Serialiser.
Ingen is a god-fearing proper Queen's english speaking upstanding gentleman of a project, cherrio, pip-pip, indeed, etc. git-svn-id: http://svn.drobilla.net/lad/ingen@849 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src')
-rw-r--r--src/libs/gui/PatchCanvas.cpp6
-rw-r--r--src/libs/gui/ThreadedLoader.hpp6
-rw-r--r--src/libs/gui/UploadPatchWindow.cpp4
-rw-r--r--src/libs/serialisation/Makefile.am4
-rw-r--r--src/libs/serialisation/Serialiser.cpp (renamed from src/libs/serialisation/Serializer.cpp)36
-rw-r--r--src/libs/serialisation/Serialiser.hpp (renamed from src/libs/serialisation/Serializer.hpp)10
6 files changed, 33 insertions, 33 deletions
diff --git a/src/libs/gui/PatchCanvas.cpp b/src/libs/gui/PatchCanvas.cpp
index f991df8e..a02235bf 100644
--- a/src/libs/gui/PatchCanvas.cpp
+++ b/src/libs/gui/PatchCanvas.cpp
@@ -22,7 +22,7 @@
#include <flowcanvas/Canvas.hpp>
#include <flowcanvas/Ellipse.hpp>
#include "interface/EngineInterface.hpp"
-#include "serialisation/Serializer.hpp"
+#include "serialisation/Serialiser.hpp"
#include "client/PluginModel.hpp"
#include "client/PatchModel.hpp"
#include "client/NodeModel.hpp"
@@ -41,7 +41,7 @@
#include "GladeFactory.hpp"
#include "WindowFactory.hpp"
using Ingen::Client::Store;
-using Ingen::Serialisation::Serializer;
+using Ingen::Serialisation::Serialiser;
using Ingen::Client::PluginModel;
namespace Ingen {
@@ -458,7 +458,7 @@ PatchCanvas::destroy_selection()
void
PatchCanvas::copy_selection()
{
- Serializer serializer(*App::instance().world()->rdf_world);
+ Serialiser serializer(*App::instance().world()->rdf_world);
serializer.start_to_string();
for (list<boost::shared_ptr<Item> >::iterator m = _selected_items.begin(); m != _selected_items.end(); ++m) {
diff --git a/src/libs/gui/UploadPatchWindow.cpp b/src/libs/gui/UploadPatchWindow.cpp
index b804796f..a31f0cf0 100644
--- a/src/libs/gui/UploadPatchWindow.cpp
+++ b/src/libs/gui/UploadPatchWindow.cpp
@@ -24,7 +24,7 @@
#include <raul/RDFQuery.hpp>
#include "module/module.h"
#include "interface/EngineInterface.hpp"
-#include "serialisation/Serializer.hpp"
+#include "serialisation/Serialiser.hpp"
#include "client/PatchModel.hpp"
#include "UploadPatchWindow.hpp"
#include "App.hpp"
@@ -248,7 +248,7 @@ UploadPatchWindow::upload_clicked()
_upload_progress->set_fraction(0.0);
_upload_progress->set_text("");
- Serializer s(*App::instance().world()->rdf_world);
+ Serialiser s(*App::instance().world()->rdf_world);
s.start_to_string();
s.serialize(_patch);
const string str = s.finish();
diff --git a/src/libs/serialisation/Makefile.am b/src/libs/serialisation/Makefile.am
index eff5a7a4..0a914222 100644
--- a/src/libs/serialisation/Makefile.am
+++ b/src/libs/serialisation/Makefile.am
@@ -11,8 +11,8 @@ libingen_serialisation_la_LIBADD = @RAUL_LIBS@ @GLIBMM_LIBS@
libingen_serialisation_la_SOURCES = \
Loader.cpp \
Loader.hpp \
- Serializer.cpp \
- Serializer.hpp \
+ Serialiser.cpp \
+ Serialiser.hpp \
serialisation.cpp \
serialisation.hpp
diff --git a/src/libs/serialisation/Serializer.cpp b/src/libs/serialisation/Serialiser.cpp
index 7483ae5e..15b7f753 100644
--- a/src/libs/serialisation/Serializer.cpp
+++ b/src/libs/serialisation/Serialiser.cpp
@@ -40,7 +40,7 @@
#include "interface/Node.hpp"
#include "interface/Port.hpp"
#include "interface/Connection.hpp"
-#include "Serializer.hpp"
+#include "Serialiser.hpp"
using namespace std;
using namespace Raul;
@@ -52,13 +52,13 @@ namespace Ingen {
namespace Serialisation {
-Serializer::Serializer(Raul::RDF::World& world)
+Serialiser::Serialiser(Raul::RDF::World& world)
: _world(world)
{
}
void
-Serializer::to_file(SharedPtr<GraphObject> object, const string& filename)
+Serialiser::to_file(SharedPtr<GraphObject> object, const string& filename)
{
_root_object = object;
start_to_filename(filename);
@@ -68,7 +68,7 @@ Serializer::to_file(SharedPtr<GraphObject> object, const string& filename)
string
-Serializer::to_string(SharedPtr<GraphObject> object)
+Serialiser::to_string(SharedPtr<GraphObject> object)
{
_root_object = object;
start_to_string();
@@ -82,7 +82,7 @@ Serializer::to_string(SharedPtr<GraphObject> object)
* This must be called before any serializing methods.
*/
void
-Serializer::start_to_filename(const string& filename)
+Serialiser::start_to_filename(const string& filename)
{
setlocale(LC_NUMERIC, "C");
@@ -100,7 +100,7 @@ Serializer::start_to_filename(const string& filename)
* the desired objects have been serialized.
*/
void
-Serializer::start_to_string()
+Serialiser::start_to_string()
{
setlocale(LC_NUMERIC, "C");
@@ -116,7 +116,7 @@ Serializer::start_to_string()
* will be returned, otherwise the empty string is returned.
*/
string
-Serializer::finish()
+Serialiser::finish()
{
string ret = "";
@@ -135,7 +135,7 @@ Serializer::finish()
/** Convert a path to an RDF blank node ID for serializing.
*/
RDF::Node
-Serializer::path_to_node_id(const Path& path)
+Serialiser::path_to_node_id(const Path& path)
{
assert(_model);
/*string ret = path.substr(1);
@@ -175,7 +175,7 @@ Serializer::path_to_node_id(const Path& path)
* be a good idea to pass as additional_path, in the case of a subpatch.
*/
string
-Serializer::find_file(const string& filename, const string& additional_path)
+Serialiser::find_file(const string& filename, const string& additional_path)
{
string search_path = additional_path + ":" + _patch_search_path;
@@ -205,7 +205,7 @@ Serializer::find_file(const string& filename, const string& additional_path)
is.close();
return full_patch_path;
} else {
- cerr << "[Serializer] Could not find patch file " << full_patch_path << endl;
+ cerr << "[Serialiser] Could not find patch file " << full_patch_path << endl;
}
}
@@ -214,7 +214,7 @@ Serializer::find_file(const string& filename, const string& additional_path)
#endif
void
-Serializer::serialize(SharedPtr<GraphObject> object) throw (std::logic_error)
+Serialiser::serialize(SharedPtr<GraphObject> object) throw (std::logic_error)
{
if (!_model)
throw std::logic_error("serialize called without serialization in progress");
@@ -237,13 +237,13 @@ Serializer::serialize(SharedPtr<GraphObject> object) throw (std::logic_error)
return;
}
- cerr << "[Serializer] WARNING: Unsupported object type, "
+ cerr << "[Serialiser] WARNING: Unsupported object type, "
<< object->path() << " not serialized." << endl;
}
RDF::Node
-Serializer::patch_path_to_rdf_id(const Path& path)
+Serialiser::patch_path_to_rdf_id(const Path& path)
{
if (path == _root_object->path()) {
return RDF::Node(_model->world(), RDF::Node::RESOURCE, _base_uri);
@@ -256,7 +256,7 @@ Serializer::patch_path_to_rdf_id(const Path& path)
void
-Serializer::serialize_patch(SharedPtr<Shared::Patch> patch)
+Serialiser::serialize_patch(SharedPtr<Shared::Patch> patch)
{
assert(_model);
@@ -321,7 +321,7 @@ Serializer::serialize_patch(SharedPtr<Shared::Patch> patch)
void
-Serializer::serialize_plugin(SharedPtr<Shared::Plugin> plugin)
+Serialiser::serialize_plugin(SharedPtr<Shared::Plugin> plugin)
{
assert(_model);
@@ -335,7 +335,7 @@ Serializer::serialize_plugin(SharedPtr<Shared::Plugin> plugin)
void
-Serializer::serialize_node(SharedPtr<Shared::Node> node, const RDF::Node& node_id)
+Serialiser::serialize_node(SharedPtr<Shared::Node> node, const RDF::Node& node_id)
{
const RDF::Node plugin_id
= RDF::Node(_model->world(), RDF::Node::RESOURCE, node->plugin()->uri());
@@ -386,7 +386,7 @@ Serializer::serialize_node(SharedPtr<Shared::Node> node, const RDF::Node& node_i
* Audio output ports with no metadata will not be written, for example.
*/
void
-Serializer::serialize_port(const Port* port, const RDF::Node& port_id)
+Serialiser::serialize_port(const Port* port, const RDF::Node& port_id)
{
if (port->is_input())
_model->add_statement(port_id, "rdf:type",
@@ -418,7 +418,7 @@ Serializer::serialize_port(const Port* port, const RDF::Node& port_id)
void
-Serializer::serialize_connection(SharedPtr<Connection> connection) throw (std::logic_error)
+Serialiser::serialize_connection(SharedPtr<Connection> connection) throw (std::logic_error)
{
if (!_model)
throw std::logic_error("serialize_connection called without serialization in progress");
diff --git a/src/libs/serialisation/Serializer.hpp b/src/libs/serialisation/Serialiser.hpp
index ead392bc..23d10c82 100644
--- a/src/libs/serialisation/Serializer.hpp
+++ b/src/libs/serialisation/Serialiser.hpp
@@ -15,8 +15,8 @@
* 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
-#ifndef SERIALIZER_H
-#define SERIALIZER_H
+#ifndef SERIALISER_H
+#define SERIALISER_H
#include <map>
#include <utility>
@@ -50,10 +50,10 @@ namespace Serialisation {
*
* \ingroup IngenClient
*/
-class Serializer
+class Serialiser
{
public:
- Serializer(Raul::RDF::World& world);
+ Serialiser(Raul::RDF::World& world);
void to_file(SharedPtr<GraphObject> object, const string& filename);
string to_string(SharedPtr<GraphObject> object);
@@ -93,4 +93,4 @@ private:
} // namespace Serialisation
} // namespace Ingen
-#endif // SERIALIZER_H
+#endif // SERIALISER_H
diff --git a/src/libs/gui/ThreadedLoader.hpp b/src/libs/gui/ThreadedLoader.hpp
index 8d140c26..d0f171af 100644
--- a/src/libs/gui/ThreadedLoader.hpp
+++ b/src/libs/gui/ThreadedLoader.hpp
@@ -28,7 +28,7 @@
#include "interface/EngineInterface.hpp"
#include "client/PatchModel.hpp"
#include "client/DeprecatedLoader.hpp"
-#include "serialisation/Serializer.hpp"
+#include "serialisation/Serialiser.hpp"
#include "serialisation/Loader.hpp"
using std::string;
using std::list;
@@ -59,7 +59,7 @@ public:
~ThreadedLoader();
// FIXME: there's a pattern here....
// (same core interface as Loader/Serializer)
void load_patch(bool merge,
const string& data_base_uri,
@@ -85,7 +85,7 @@ private:
SharedPtr<Loader> _loader;
DeprecatedLoader _deprecated_loader;
- Serializer _serializer;
+ Serialiser _serializer;
Glib::Mutex _mutex;
list<Closure> _events;
};
@@ -59,7 +59,7 @@ public:
~ThreadedLoader();
// FIXME: there's a pattern here....
- // (same core interface as Loader/Serializer)
+ // (same core interface as Loader/Serialiser)
void load_patch(bool merge,
const string& data_base_uri,